==================================
dian: a symbolic power system tool
==================================

.. image:: https://img.shields.io/travis/cuihantao/dian.svg
        :target: https://travis-ci.org/cuihantao/dian

.. image:: https://codecov.io/gh/cuihantao/dian/branch/master/graph/badge.svg
    :alt: Codecov Coverage
    :target: https://codecov.io/gh/cuihantao/dian

.. image:: https://img.shields.io/pypi/v/dian.svg
        :target: https://pypi.python.org/pypi/dian

* Free software: GNU Public License (GPL) v3
* Documentation: (coming soon!) https://dian.readthedocs.io

FEATURES
--------
* Symbolic power flow analysis

Acknowledgement
---------------
This work was supported in part by the Engineering Research Center Program of
the National Science Foundation and the Department of Energy under NSF Award
Number EEC-1041877 and the CURENT Industry Partnership Program.